import { Environment, Implementation, Widget, ImplementationConfiguration, ImplementationSelector, ConfigureCallback } from '@webprovisions/platform';
export declare function attach(widget: Widget, ...triggerElements: HTMLElement[]): Promise<Widget>;
export declare function scan(implementation: BootstrappedImplementation, rootElement?: HTMLElement | Document): Promise<Widget[]>;
export declare type ConfigurationHandler = (...args: any[]) => void;
export interface BootstrappedEnvironment extends Environment {
    /**
     * Extension method for configuring one or many implementations in the current `Environment`.
     */
    configure: (selectorOrConfigFn: (ImplementationSelector | ConfigureCallback), configFn?: ConfigureCallback) => void;
}
export interface BootstrappedImplementationConfiguration extends ImplementationConfiguration {
    bindings: string[];
}
/**
 * A bootstrapped `Implementation` with additional extension methods.
 */
export interface BootstrappedImplementation extends Implementation {
    /**
     * Array of domain names to identify during the bootstrapping.
     */
    bindings: string[];
    environment: BootstrappedEnvironment;
    /**
     * Scans the document, or the specified container element, for trigger elements.
     */
    scan: (rootElement?: HTMLElement | Document) => Promise<Widget[]>;
    /**
     * Attaches a `WidgetData` instance to additional trigger elements.
     */
    attach: (widget: Widget, ...triggerElements: HTMLElement[]) => Promise<Widget>;
}
export declare type BootstrappingData = {
    /**
     * Indicates whether the current implementation has been fully bootstrapped.
     */
    ready: boolean;
};
/**
 * Bootstraps an implementation by scanning the document, or the specified root element, for
 * trigger elements, and enables the default bootstrapping capabilities in supported widgets.
 * @param implementation Implementation to bootstrap.
 * @param createConfigurationHandlers Function for supplying default configuration handlers.
 * @param rootElementResolver Function for resolving the root element.
 */
export default function bootstrapImplementation(implementation: Implementation, bindings: string[], createConfigurationHandlers: () => ConfigurationHandler[], rootElementResolver: (() => HTMLElement)): Promise<BootstrappedImplementation>;
